# -*- coding: utf-8 -*-
from setuphelpers import *

allow_auto_remediation = True


def install():
    pass


def session_setup():
    """
    NetworkCategory:
    Public = 0
    Private = 1
    DomainAuthenticated = 2
    """
    # Getting Network Profile Informations
    net_profiles_data = run_powershell("Get-NetConnectionProfile")
    net_public_interfaces = []

    # Cleaning up the output
    del_elements = [
        "Caption",
        "CimClass",
        "CimInstanceProperties",
        "CimSystemProperties",
        "PSComputerName",
        "InstanceID",
        "IPv4Connectivity",
        "IPv6Connectivity",
        "ElementName",
    ]

    if type(net_profiles_data) == list:
        multiple_interfaces = True
    else:
        multiple_interfaces = False
    if multiple_interfaces:
        for interface in net_profiles_data:
            for elem in list(interface):
                for del_elem in del_elements:
                    if del_elem in elem:
                        del interface[del_elem]
            if interface["NetworkCategory"] == 0:
                interface_data = {
                    "InterfaceAlias": interface["InterfaceAlias"],
                    "InterfaceIndex": interface["InterfaceIndex"],
                    "NetworkCategory": interface["NetworkCategory"],
                }
                net_public_interfaces.append(interface_data)
    else:
        for elem in list(net_profiles_data):
            for del_elem in del_elements:
                if del_elem in elem:
                    del net_profiles_data[del_elem]
        if net_profiles_data["NetworkCategory"] == 0:
            interface_data = {
                "InterfaceAlias": net_profiles_data["InterfaceAlias"],
                "InterfaceIndex": net_profiles_data["InterfaceIndex"],
                "NetworkCategory": net_profiles_data["NetworkCategory"],
            }
            net_public_interfaces.append(interface_data)

    print("Network Profiles result in json format:")
    print(net_profiles_data)
    # json_write_file('net_profiles.json', net_profiles_data)

    if net_public_interfaces != []:
        print("WARNING: At least one network interface is in Public profile, you may need to execute the following command(s):")
        for pub_int in net_public_interfaces:
            print("Set-NetConnectionProfile -InterfaceIndex %s -NetworkCategory %s" % (pub_int["InterfaceIndex"], "Private"))
    else:
        print("OK: Network Interfaces are in correct profile.")


def audit():
    """
    NetworkCategory:
    Public = 0
    Private = 1
    DomainAuthenticated = 2
    """
    # Getting Network Profile Informations
    net_profiles_data = run_powershell("Get-NetConnectionProfile")
    net_public_interfaces = []

    # Cleaning up the output
    del_elements = [
        "Caption",
        "CimClass",
        "CimInstanceProperties",
        "CimSystemProperties",
        "PSComputerName",
        "InstanceID",
        "IPv4Connectivity",
        "IPv6Connectivity",
        "ElementName",
    ]

    if type(net_profiles_data) == list:
        multiple_interfaces = True
    else:
        multiple_interfaces = False
    if multiple_interfaces:
        for interface in net_profiles_data:
            for elem in list(interface):
                for del_elem in del_elements:
                    if del_elem in elem:
                        del interface[del_elem]
            if interface["NetworkCategory"] == 0:
                interface_data = {
                    "InterfaceAlias": interface["InterfaceAlias"],
                    "InterfaceIndex": interface["InterfaceIndex"],
                    "NetworkCategory": interface["NetworkCategory"],
                }
                net_public_interfaces.append(interface_data)
    else:
        for elem in list(net_profiles_data):
            for del_elem in del_elements:
                if del_elem in elem:
                    del net_profiles_data[del_elem]
        if net_profiles_data["NetworkCategory"] == 0:
            interface_data = {
                "InterfaceAlias": net_profiles_data["InterfaceAlias"],
                "InterfaceIndex": net_profiles_data["InterfaceIndex"],
                "NetworkCategory": net_profiles_data["NetworkCategory"],
            }
            net_public_interfaces.append(interface_data)

    print("Network Profiles result in json format:")
    print(net_profiles_data)
    # json_write_file('net_profiles.json', net_profiles_data)

    if allow_auto_remediation:
        if net_public_interfaces != []:
            print("WARNING: At least one network interface is in Public profile, switching it to Private profile...")
            for pub_int in net_public_interfaces:
                WAPT.write_audit_data("audit-network-profile", "auto-remediate-card", pub_int["InterfaceAlias"], keep_days=365)
                print(
                    "Switching Interface: %s (Interface Index: %s) from: Public profile to: Private profile"
                    % (pub_int["InterfaceAlias"], pub_int["InterfaceIndex"])
                )
                print("Set-NetConnectionProfile -InterfaceIndex %s -NetworkCategory %s" % (pub_int["InterfaceIndex"], "Private"))
                run_powershell("Set-NetConnectionProfile -InterfaceIndex %s -NetworkCategory %s" % (pub_int["InterfaceIndex"], "Private"))
            return "WARNING"

    if net_public_interfaces != []:
        print("WARNING: At least one network interface is in Public profile, you may need to execute the following command(s):")
        for pub_int in net_public_interfaces:
            print("Set-NetConnectionProfile -InterfaceIndex %s -NetworkCategory %s" % (pub_int["InterfaceIndex"], "Private"))
        return "WARNING"
    else:
        print("OK: Network Interfaces are in correct profile.")
        return "OK"


def remove_extra_keys(dictionnary, list_keys):
    # .keys() permit to delete dynamicaly values in a dict
    for elem in list(dictionnary):
        for del_elem in list_keys:
            if del_elem in elem:
                del dictionnary[del_elem]
    return dictionnary
